Learn R Programming

LANDD (version 1.1.0)

xw.distance: Create a table to record the distance between gene x and gene w.

Description

xw.distance() generates a table contains distance between all genes x and their correspongding genes w.

Usage

xw.distance(graph, z.matrix, cutoff = 0.8, n.cores = 4)

Arguments

graph
The graph of the gene network.
z.matrix
A matrix representing gene Z. Row names are the gene id in gene network.
cutoff
A number used to find LA scouting gene z.
n.cores
Core number used for parallel computing.

Value

a table contains distance between all genes x and their correspongding genes w.

Examples

Run this code
## Not run:  xw.distance(g,m,cutoff=0.8,n.cores=4)

Run the code above in your browser using DataLab